@@ -39,6 +39,7 @@
 #include "empathy-contact-dialogs.h"
 #include "empathy-ui-utils.h"
 #include "empathy-share-my-desktop.h"
+#include "empathy-call-utils.h"
 
 static GtkWidget *empathy_contact_block_menu_item_new (EmpathyContact *);
 
@@ -343,7 +344,9 @@ static void
 empathy_contact_audio_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-	empathy_call_new_with_streams (contact, TRUE, FALSE,
+	empathy_call_new_with_streams (empathy_contact_get_id (contact),
+		empathy_contact_get_account (contact),
+		TRUE, FALSE,
 		empathy_get_current_action_time ());
 }
 
@@ -374,7 +377,9 @@ static void
 empathy_contact_video_call_menu_item_activated (GtkMenuItem *item,
 	EmpathyContact *contact)
 {
-	empathy_call_new_with_streams (contact, TRUE, TRUE,
+	empathy_call_new_with_streams (empathy_contact_get_id (contact),
+		empathy_contact_get_account (contact),
+		TRUE, TRUE,
 		empathy_get_current_action_time ());
 }
 
