@@ -40,6 +40,7 @@
 #include <libempathy/empathy-contact-manager.h>
 #include <libempathy/empathy-contact-list.h>
 #include <libempathy/empathy-location.h>
+#include <libempathy/empathy-request-util.h>
 #include <libempathy/empathy-time.h>
 #include <libempathy/empathy-utils.h>
 
@@ -76,6 +77,8 @@
 /* Delay before updating the widget when the id entry changed (seconds) */
 #define ID_CHANGED_TIMEOUT 1
 
+#define DATA_FIELD "contact-info-field"
+
 typedef struct
 {
   EmpathyContactManager *manager;
@@ -123,6 +126,7 @@ typedef struct
   GtkWidget *spinner_details;
   GList *details_to_set;
   GCancellable *details_cancellable;
+  gboolean details_changed;
 
   /* Client */
   GtkWidget *vbox_client;
@@ -207,8 +211,12 @@ contact_widget_save (EmpathyContactWidget *information)
 
   if (information->details_to_set != NULL)
     {
-      tp_connection_set_contact_info_async (connection,
-          information->details_to_set, set_contact_info_cb, NULL);
+      if (information->details_changed)
+        {
+          tp_connection_set_contact_info_async (connection,
+              information->details_to_set, set_contact_info_cb, NULL);
+        }
+
       tp_contact_info_list_free (information->details_to_set);
       information->details_to_set = NULL;
     }
@@ -227,9 +235,15 @@ contact_widget_details_setup (EmpathyContactWidget *information)
 
 static void
 contact_widget_details_changed_cb (GtkEntry *entry,
-    TpContactInfoField *field)
+    EmpathyContactWidget *self)
 {
   const gchar *strv[] = { NULL, NULL };
+  TpContactInfoField *field;
+
+  self->details_changed = TRUE;
+
+  field = g_object_get_data ((GObject *) entry, DATA_FIELD);
+  g_assert (field != NULL);
 
   strv[0] = gtk_entry_get_text (entry);
 
@@ -238,22 +252,106 @@ contact_widget_details_changed_cb (GtkEntry *entry,
   field->field_value = g_strdupv ((GStrv) strv);
 }
 
+static void
+contact_widget_bday_changed_cb (GtkCalendar *calendar,
+    EmpathyContactWidget *self)
+{
+  guint year, month, day;
+  GDate *date;
+  gchar tmp[255];
+  const gchar *strv[] = { NULL, NULL };
+  TpContactInfoField *field;
+
+  self->details_changed = TRUE;
+
+  field = g_object_get_data ((GObject *) calendar, DATA_FIELD);
+  g_assert (field != NULL);
+
+  gtk_calendar_get_date (calendar, &year, &month, &day);
+  date = g_date_new_dmy (day, month+1, year);
+
+  gtk_calendar_clear_marks (calendar);
+  gtk_calendar_mark_day (calendar, g_date_get_day (date));
+
+  g_date_strftime (tmp, sizeof (tmp), EMPATHY_DATE_FORMAT_DISPLAY_SHORT, date);
+  strv[0] = tmp;
+  if (field->field_value != NULL)
+    g_strfreev (field->field_value);
+  field->field_value = g_strdupv ((GStrv) strv);
+
+  g_date_free (date);
+}
+
 static void contact_widget_details_notify_cb (EmpathyContactWidget *information);
 
+typedef gchar * (* FieldFormatFunc) (GStrv);
+
 typedef struct
 {
   const gchar *field_name;
   const gchar *title;
-  gboolean linkify;
+  FieldFormatFunc format;
 } InfoFieldData;
 
+static gchar *
+linkify_first_value (GStrv values)
+{
+  return empathy_add_link_markup (values[0]);
+}
+
+static gchar *
+format_idle_time (GStrv values)
+{
+  const gchar *value = values[0];
+  int duration = strtol (value, NULL, 10);
+
+  if (duration <= 0)
+    return NULL;
+
+  return empathy_duration_to_string (duration);
+}
+
+static gchar *
+format_server (GStrv values)
+{
+  g_assert (values[0] != NULL);
+
+  if (values[1] == NULL)
+    return g_markup_escape_text (values[0], -1);
+  else
+    return g_markup_printf_escaped ("%s (%s)", values[0], values[1]);
+}
+
+static gchar *
+presence_hack (GStrv values)
+{
+  if (tp_str_empty (values[0]))
+    return NULL;
+
+  return g_markup_escape_text (values[0], -1);
+}
+
 static InfoFieldData info_field_datas[] =
 {
-  { "fn",    N_("Full name:"),      FALSE },
-  { "tel",   N_("Phone number:"),   FALSE },
-  { "email", N_("E-mail address:"), TRUE },
-  { "url",   N_("Website:"),        TRUE },
-  { "bday",  N_("Birthday:"),       FALSE },
+  { "fn",    N_("Full name:"),      NULL },
+  { "tel",   N_("Phone number:"),   NULL },
+  { "email", N_("E-mail address:"), linkify_first_value },
+  { "url",   N_("Website:"),        linkify_first_value },
+  { "bday",  N_("Birthday:"),       NULL },
+
+  /* Note to translators: this is the caption for a string of the form "5
+   * minutes ago", and refers to the time since the contact last interacted
+   * with their IM client.
+   */
+  { "x-idle-time", N_("Last seen:"), format_idle_time },
+  { "x-irc-server", N_("Server:"), format_server },
+  { "x-host", N_("Connected from:"), format_server },
+
+  /* FIXME: once Idle implements SimplePresence using this information, we can
+   * and should bin this.
+   */
+  { "x-presence-status-message", N_("Away message:"), presence_hack },
+
   { NULL, NULL }
 };
 
@@ -344,6 +442,8 @@ contact_widget_details_update_edit (EmpathyContactWidget *information)
 
   g_assert (information->details_to_set == NULL);
 
+  information->details_changed = FALSE;
+
   contact = empathy_contact_get_tp_contact (information->contact);
   connection = tp_contact_get_connection (contact);
 
@@ -396,6 +496,7 @@ contact_widget_details_update_edit (EmpathyContactWidget *information)
       TpContactInfoField *field = l->data;
       InfoFieldData *field_data;
       GtkWidget *w;
+      TpContactInfoFieldSpec *spec;
 
       field_data = find_info_field_data (field->field_name);
       if (field_data == NULL)
@@ -407,59 +508,15 @@ contact_widget_details_update_edit (EmpathyContactWidget *information)
           continue;
         }
 
-      /* Add Title */
-      w = gtk_label_new (_(field_data->title));
-      gtk_table_attach (GTK_TABLE (information->table_details),
-          w, 0, 1, n_rows, n_rows + 1, GTK_FILL, 0, 0, 0);
-      gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
-      gtk_widget_show (w);
+      spec = get_spec_from_list (specs, field->field_name);
+      /* We shouldn't have added the field to details_to_set if it's not
+       * supported by the CM */
+      g_assert (spec != NULL);
 
-      /* Add Value */
-      w = gtk_entry_new ();
-      gtk_entry_set_text (GTK_ENTRY (w),
-          field->field_value[0] ? field->field_value[0] : "");
-      gtk_table_attach_defaults (GTK_TABLE (information->table_details),
-          w, 1, 2, n_rows, n_rows + 1);
-      gtk_widget_show (w);
-
-      g_signal_connect (w, "changed",
-        G_CALLBACK (contact_widget_details_changed_cb), field);
-
-      n_rows++;
-    }
-
-  g_list_free (specs);
-  g_list_free (info);
-
-  return n_rows;
-}
-
-static guint
-contact_widget_details_update_show (EmpathyContactWidget *information)
-{
-  TpContact *contact;
-  GList *info, *l;
-  guint n_rows = 0;
-
-  contact = empathy_contact_get_tp_contact (information->contact);
-  info = tp_contact_get_contact_info (contact);
-  info = g_list_sort (info, (GCompareFunc) contact_info_field_cmp);
-  for (l = info; l != NULL; l = l->next)
-    {
-      TpContactInfoField *field = l->data;
-      InfoFieldData *field_data;
-      const gchar *value;
-      GtkWidget *w;
-
-      if (field->field_value == NULL || field->field_value[0] == NULL)
-        continue;
-
-      value = field->field_value[0];
-
-      field_data = find_info_field_data (field->field_name);
-      if (field_data == NULL)
+      if (spec->flags & TP_CONTACT_INFO_FIELD_FLAG_OVERWRITTEN_BY_NICKNAME)
         {
-          DEBUG ("Unhandled ContactInfo field: %s", field->field_name);
+          DEBUG ("Ignoring field '%s' due it to having the "
+              "Overwritten_By_Nickname flag", field->field_name);
           continue;
         }
 
@@ -471,12 +528,179 @@ contact_widget_details_update_show (EmpathyContactWidget *information)
       gtk_widget_show (w);
 
       /* Add Value */
-      w = gtk_label_new (value);
-      if (field_data->linkify)
+      if (!tp_strdiff (field->field_name, "bday"))
         {
-          gchar *markup;
+          w = gtk_calendar_new ();
+          if (field->field_value[0])
+            {
+              GDate date;
 
-          markup = empathy_add_link_markup (value);
+              g_date_set_parse (&date, field->field_value[0]);
+              if (g_date_valid (&date))
+                {
+                  gtk_calendar_select_day (GTK_CALENDAR (w),
+                      g_date_get_day (&date));
+                  gtk_calendar_select_month (GTK_CALENDAR (w),
+                      g_date_get_month (&date) - 1, g_date_get_year (&date));
+                  gtk_calendar_mark_day (GTK_CALENDAR (w),
+                      g_date_get_day (&date));
+                }
+            }
+          gtk_table_attach_defaults (GTK_TABLE (information->table_details),
+              w, 1, 2, n_rows, n_rows + 1);
+          gtk_widget_show (w);
+
+          g_object_set_data ((GObject *) w, DATA_FIELD, field);
+
+          g_signal_connect (w, "day-selected-double-click",
+            G_CALLBACK (contact_widget_bday_changed_cb), information);
+          g_signal_connect (w, "month-changed",
+            G_CALLBACK (contact_widget_bday_changed_cb), information);
+        }
+      else
+        {
+          w = gtk_entry_new ();
+          gtk_entry_set_text (GTK_ENTRY (w),
+              field->field_value[0] ? field->field_value[0] : "");
+          gtk_table_attach_defaults (GTK_TABLE (information->table_details),
+              w, 1, 2, n_rows, n_rows + 1);
+          gtk_widget_show (w);
+
+          g_object_set_data ((GObject *) w, DATA_FIELD, field);
+
+          g_signal_connect (w, "changed",
+            G_CALLBACK (contact_widget_details_changed_cb), information);
+        }
+
+      n_rows++;
+    }
+
+  g_list_free (specs);
+  g_list_free (info);
+
+  return n_rows;
+}
+
+static gboolean
+channel_name_activated_cb (
+    GtkLabel *label,
+    gchar *uri,
+    EmpathyContactWidget *information)
+{
+  TpAccount *account = empathy_contact_get_account (information->contact);
+
+  empathy_join_muc (account, uri, empathy_get_current_action_time ());
+  return TRUE;
+}
+
+static void
+add_channel_list (
+    EmpathyContactWidget *information,
+    GPtrArray *channels,
+    guint row)
+{
+  GtkWidget *w;
+  GString *label_markup = g_string_new ("");
+  guint i;
+
+  w = gtk_label_new (_("Channels:"));
+  gtk_table_attach (GTK_TABLE (information->table_details),
+      w, 0, 1, row, row + 1, GTK_FILL, 0, 0, 0);
+  gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+  gtk_widget_show (w);
+
+  for (i = 0; i < channels->len; i++)
+    {
+      const gchar *channel_name = g_ptr_array_index (channels, i);
+      /* We abuse the URI of the link to hold the channel name. It seems to
+       * be okay to just use it essentially verbatim, rather than trying to
+       * ensure it's actually a valid URI.  g_string_append_uri_escaped()
+       * escapes way more than we actually need to; so we're just using
+       * g_markup_escape_text directly.
+       */
+      gchar *escaped = g_markup_escape_text (channel_name, -1);
+
+      if (i > 0)
+        g_string_append (label_markup, ", ");
+
+      g_string_append_printf (label_markup, "<a href='%s'>%s</a>",
+          escaped, channel_name);
+      g_free (escaped);
+    }
+
+  w = gtk_label_new (NULL);
+  gtk_label_set_markup (GTK_LABEL (w), label_markup->str);
+  gtk_label_set_line_wrap (GTK_LABEL (w), TRUE);
+  g_signal_connect (w, "activate-link",
+      (GCallback) channel_name_activated_cb, information);
+  gtk_table_attach_defaults (GTK_TABLE (information->table_details),
+      w, 1, 2, row, row + 1);
+  gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+  gtk_widget_show (w);
+
+  g_string_free (label_markup, TRUE);
+}
+
+static guint
+contact_widget_details_update_show (EmpathyContactWidget *information)
+{
+  TpContact *contact;
+  GList *info, *l;
+  guint n_rows = 0;
+  GPtrArray *channels = g_ptr_array_new ();
+
+  contact = empathy_contact_get_tp_contact (information->contact);
+  info = tp_contact_get_contact_info (contact);
+  info = g_list_sort (info, (GCompareFunc) contact_info_field_cmp);
+  for (l = info; l != NULL; l = l->next)
+    {
+      TpContactInfoField *field = l->data;
+      InfoFieldData *field_data;
+      const gchar *value;
+      gchar *markup = NULL;
+      GtkWidget *w;
+
+      if (field->field_value == NULL || field->field_value[0] == NULL)
+        continue;
+
+      value = field->field_value[0];
+
+      if (!tp_strdiff (field->field_name, "x-irc-channel"))
+        {
+          g_ptr_array_add (channels, (gpointer) field->field_value[0]);
+          continue;
+        }
+
+      field_data = find_info_field_data (field->field_name);
+      if (field_data == NULL)
+        {
+          DEBUG ("Unhandled ContactInfo field: %s", field->field_name);
+          continue;
+        }
+
+      if (field_data->format != NULL)
+        {
+          markup = field_data->format (field->field_value);
+
+          if (markup == NULL)
+            {
+              DEBUG ("Invalid value for field '%s' (first element was '%s')",
+                  field->field_name, field->field_value[0]);
+              continue;
+            }
+        }
+
+      /* Add Title */
+      w = gtk_label_new (_(field_data->title));
+      gtk_table_attach (GTK_TABLE (information->table_details),
+          w, 0, 1, n_rows, n_rows + 1, GTK_FILL, 0, 0, 0);
+      gtk_misc_set_alignment (GTK_MISC (w), 0, 0.5);
+      gtk_widget_show (w);
+
+      /* Add Value */
+      w = gtk_label_new (value);
+      if (markup != NULL)
+        {
           gtk_label_set_markup (GTK_LABEL (w), markup);
           g_free (markup);
         }
@@ -493,6 +717,13 @@ contact_widget_details_update_show (EmpathyContactWidget *information)
     }
   g_list_free (info);
 
+  if (channels->len > 0)
+    {
+      add_channel_list (information, channels, n_rows);
+      n_rows++;
+    }
+
+  g_ptr_array_unref (channels);
   return n_rows;
 }
 
@@ -561,16 +792,14 @@ contact_widget_details_request_cb (GObject *object,
 }
 
 static void
-contact_widget_details_feature_prepared_cb (GObject *object,
-    GAsyncResult *res,
-    gpointer user_data)
+fetch_contact_information (EmpathyContactWidget *information,
+        TpConnection *connection)
 {
-  TpConnection *connection = TP_CONNECTION (object);
-  EmpathyContactWidget *information = user_data;
   TpContact *contact;
   TpContactInfoFlags flags;
 
-  if (!tp_proxy_prepare_finish (connection, res, NULL))
+  if (!tp_proxy_has_interface_by_id (connection,
+          TP_IFACE_QUARK_CONNECTION_INTERFACE_CONTACT_INFO))
     {
       gtk_widget_hide (information->vbox_details);
       return;
@@ -615,13 +844,11 @@ contact_widget_details_update (EmpathyContactWidget *information)
 
   if (tp_contact != NULL)
     {
-      GQuark features[] = { TP_CONNECTION_FEATURE_CONTACT_INFO, 0 };
       TpConnection *connection;
 
-      /* First, make sure the CONTACT_INFO feature is ready on the connection */
       connection = tp_contact_get_connection (tp_contact);
-      tp_proxy_prepare_async (connection, features,
-          contact_widget_details_feature_prepared_cb, information);
+
+      fetch_contact_information (information, connection);
     }
 }
 
@@ -647,11 +874,11 @@ contact_widget_groups_update (EmpathyContactWidget *information)
       FolksPersona *persona =
           empathy_contact_get_persona (information->contact);
 
-      if (FOLKS_IS_GROUPABLE (persona))
+      if (FOLKS_IS_GROUP_DETAILS (persona))
         {
-          empathy_groups_widget_set_groupable (
+          empathy_groups_widget_set_group_details (
               EMPATHY_GROUPS_WIDGET (information->groups_widget),
-              FOLKS_GROUPABLE (persona));
+              FOLKS_GROUP_DETAILS (persona));
           gtk_widget_show (information->groups_widget);
 
           return;
@@ -726,8 +953,10 @@ contact_widget_location_update (EmpathyContactWidget *information)
 {
   GHashTable *location;
   GValue *value;
+#ifdef HAVE_LIBCHAMPLAIN
   gdouble lat = 0.0, lon = 0.0;
   gboolean has_position = TRUE;
+#endif
   GtkWidget *label;
   guint row = 0;
   static const gchar* ordered_geolocation_keys[] = {
@@ -761,18 +990,6 @@ contact_widget_location_update (EmpathyContactWidget *information)
       return;
     }
 
-  value = g_hash_table_lookup (location, EMPATHY_LOCATION_LAT);
-  if (value == NULL)
-      has_position = FALSE;
-  else
-      lat = g_value_get_double (value);
-
-  value = g_hash_table_lookup (location, EMPATHY_LOCATION_LON);
-  if (value == NULL)
-      has_position = FALSE;
-  else
-      lon = g_value_get_double (value);
-
   value = g_hash_table_lookup (location, EMPATHY_LOCATION_TIMESTAMP);
   if (value == NULL)
     {
@@ -785,13 +1002,11 @@ contact_widget_location_update (EmpathyContactWidget *information)
       gchar *user_date;
       gchar *text;
       gint64 stamp;
-      time_t time_;
       gchar *tmp;
 
       stamp = g_value_get_int64 (value);
-      time_ = stamp;
 
-      user_date = empathy_time_to_string_relative (time_);
+      user_date = empathy_time_to_string_relative (stamp);
 
       tmp = g_strdup_printf ("<b>%s</b>", _("Location"));
       /* translators: format is "Location, $date" */
@@ -844,7 +1059,7 @@ contact_widget_location_update (EmpathyContactWidget *information)
         }
       else if (G_VALUE_TYPE (gvalue) == G_TYPE_INT64)
         {
-          time_t time_;
+          gint64 time_;
 
           time_ = g_value_get_int64 (value);
           svalue = empathy_time_to_string_utc (time_, _("%B %e, %Y at %R UTC"));
@@ -892,7 +1107,7 @@ contact_widget_location_update (EmpathyContactWidget *information)
   if (display_map)
     {
       ClutterActor *marker;
-      ChamplainLayer *layer;
+      ChamplainMarkerLayer *layer;
 
       information->map_view_embed = gtk_champlain_embed_new ();
       information->map_view = gtk_champlain_embed_get_view (
@@ -901,18 +1116,17 @@ contact_widget_location_update (EmpathyContactWidget *information)
       gtk_container_add (GTK_CONTAINER (information->viewport_map),
           information->map_view_embed);
       g_object_set (G_OBJECT (information->map_view),
-          "show-license", TRUE,
-          "scroll-mode", CHAMPLAIN_SCROLL_MODE_KINETIC,
+          "kinetic-mode", TRUE,
           "zoom-level", 10,
           NULL);
 
-      layer = champlain_layer_new ();
-      champlain_view_add_layer (information->map_view, layer);
+      layer = champlain_marker_layer_new ();
+      champlain_view_add_layer (information->map_view, CHAMPLAIN_LAYER (layer));
 
-      marker = champlain_marker_new_with_text (
+      marker = champlain_label_new_with_text (
           empathy_contact_get_alias (information->contact), NULL, NULL, NULL);
-      champlain_base_marker_set_position (CHAMPLAIN_BASE_MARKER (marker), lat, lon);
-      clutter_container_add (CLUTTER_CONTAINER (layer), marker, NULL);
+      champlain_location_set_location (CHAMPLAIN_LOCATION (marker), lat, lon);
+      champlain_marker_layer_add_marker (layer, CHAMPLAIN_MARKER (marker));
 
       champlain_view_center_on (information->map_view, lat, lon);
       gtk_widget_show_all (information->viewport_map);
@@ -1017,7 +1231,7 @@ popup_avatar_menu (EmpathyContactWidget *information,
       empathy_contact_get_avatar (information->contact) == NULL)
       return;
 
-  menu = gtk_menu_new ();
+  menu = empathy_context_menu_new (parent);
 
   /* Add "Save as..." entry */
   item = gtk_image_menu_item_new_from_stock (GTK_STOCK_SAVE_AS, NULL);
@@ -1040,8 +1254,6 @@ popup_avatar_menu (EmpathyContactWidget *information,
 
   gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL,
       button, event_time);
-  g_object_ref_sink (menu);
-  g_object_unref (menu);
 }
 
 static gboolean
@@ -1125,13 +1337,44 @@ set_nickname_cb (GObject *source,
     }
 }
 
+/* Update all the contact info fields having the
+* Overwritten_By_Nickname flag to the new alias. This avoid accidentally
+* reseting the alias when calling SetContactInfo(). See bgo #644298 for
+* details. */
 static void
-set_alias_on_account (TpAccount *account,
-    const gchar *alias)
+update_nickname_in_contact_info (EmpathyContactWidget *self,
+    TpConnection *connection,
+    const gchar *nickname)
 {
-  DEBUG ("Set Account.Nickname to %s", alias);
+  GList *specs, *l;
 
-  tp_account_set_nickname_async (account, alias, set_nickname_cb, NULL);
+  specs = tp_connection_get_contact_info_supported_fields (connection);
+
+  for (l = self->details_to_set; l != NULL; l= g_list_next (l))
+    {
+      TpContactInfoField *field = l->data;
+      TpContactInfoFieldSpec *spec;
+
+      spec = get_spec_from_list (specs, field->field_name);
+      /* We shouldn't have added the field to details_to_set if it's not
+       * supported by the CM */
+      g_assert (spec != NULL);
+
+      if (spec->flags & TP_CONTACT_INFO_FIELD_FLAG_OVERWRITTEN_BY_NICKNAME)
+        {
+          const gchar *strv[] = { nickname, NULL };
+
+          DEBUG ("Updating field '%s' to '%s' as it has the "
+              "Overwritten_By_Nickname flag and Account.Nickname has "
+              "been updated", field->field_name, nickname);
+
+          if (field->field_value != NULL)
+            g_strfreev (field->field_value);
+          field->field_value = g_strdupv ((GStrv) strv);
+        }
+    }
+
+  g_list_free (specs);
 }
 
 static gboolean
@@ -1148,9 +1391,21 @@ contact_widget_entry_alias_focus_event_cb (GtkEditable *editable,
       if (empathy_contact_is_user (information->contact))
         {
           TpAccount * account;
+          const gchar *current_nickname;
 
           account = empathy_contact_get_account (information->contact);
-          set_alias_on_account (account, alias);
+          current_nickname = tp_account_get_nickname (account);
+
+          if (tp_strdiff (current_nickname, alias))
+            {
+              DEBUG ("Set Account.Nickname to %s", alias);
+
+              tp_account_set_nickname_async (account, alias, set_nickname_cb,
+                  NULL);
+
+              update_nickname_in_contact_info (information,
+                  empathy_contact_get_connection (information->contact), alias);
+            }
         }
       else
         {
@@ -1345,10 +1600,10 @@ contact_widget_contact_update (EmpathyContactWidget *information)
           FolksPersona *persona = empathy_contact_get_persona (
               information->contact);
 
-          if (persona != NULL && FOLKS_IS_FAVOURITABLE (persona))
+          if (persona != NULL && FOLKS_IS_FAVOURITE_DETAILS (persona))
             {
-              gboolean is_favourite = folks_favouritable_get_is_favourite (
-                  FOLKS_FAVOURITABLE (persona));
+              gboolean is_favourite = folks_favourite_details_get_is_favourite (
+                  FOLKS_FAVOURITE_DETAILS (persona));
               contact_widget_favourites_changed_cb (information->manager,
                   information->contact, is_favourite, information);
             }
@@ -1479,10 +1734,11 @@ favourite_toggled_cb (GtkToggleButton *button,
 {
   FolksPersona *persona = empathy_contact_get_persona (information->contact);
 
-  if (persona != NULL && FOLKS_IS_FAVOURITABLE (persona))
+  if (persona != NULL && FOLKS_IS_FAVOURITE_DETAILS (persona))
     {
       gboolean active = gtk_toggle_button_get_active (button);
-      folks_favouritable_set_is_favourite (FOLKS_FAVOURITABLE (persona), active);
+      folks_favourite_details_set_is_favourite (
+          FOLKS_FAVOURITE_DETAILS (persona), active);
     }
 }
 
