@@ -901,7 +901,7 @@ static void
 main_window_balance_update_balance (GtkAction   *action,
 				    TpConnection *conn)
 {
-	TpAccount *account = g_object_get_data (G_OBJECT (action), "account");
+	TpAccount *account = tp_connection_get_account (conn);
 	GtkWidget *label;
 	int amount = 0;
 	guint scale = G_MAXINT32;
@@ -977,7 +977,6 @@ main_window_setup_balance_create_action (EmpathyMainWindow *window,
 	g_object_bind_property (account, "icon-name", action, "icon-name",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_set_data (G_OBJECT (action), "account", account);
 	g_signal_connect (action, "activate",
 		G_CALLBACK (main_window_balance_activate_cb), window);
 
@@ -1016,15 +1015,12 @@ main_window_setup_balance_create_action (EmpathyMainWindow *window,
 
 static GtkWidget *
 main_window_setup_balance_create_widget (EmpathyMainWindow *window,
-					 GtkAction         *action)
+					 GtkAction         *action,
+					 TpAccount *account)
 {
 	EmpathyMainWindowPriv *priv = GET_PRIV (window);
-	TpAccount *account;
 	GtkWidget *hbox, *image, *label, *button;
 
-	account = g_object_get_data (G_OBJECT (action), "account");
-	g_return_val_if_fail (TP_IS_ACCOUNT (account), NULL);
-
 	hbox = gtk_hbox_new (FALSE, 6);
 
 	/* protocol icon */
@@ -1063,24 +1059,16 @@ main_window_setup_balance_create_widget (EmpathyMainWindow *window,
 }
 
 static void
-main_window_setup_balance_conn_ready (GObject      *source,
-				      GAsyncResult *result,
-				      gpointer      user_data)
+main_window_setup_balance (EmpathyMainWindow *window,
+			   TpAccount         *account)
 {
-	EmpathyMainWindow *window = user_data;
 	EmpathyMainWindowPriv *priv = GET_PRIV (window);
-	TpConnection *conn = TP_CONNECTION (source);
-	TpAccount *account = g_object_get_data (source, "account");
+	TpConnection *conn = tp_account_get_connection (account);
 	GtkAction *action;
-	GError *error = NULL;
 	const gchar *uri;
 
-	if (!tp_proxy_prepare_finish (conn, result, &error)) {
-		DEBUG ("Failed to prepare connection: %s", error->message);
-
-		g_error_free (error);
+	if (conn == NULL)
 		return;
-	}
 
 	if (!tp_proxy_is_prepared (conn, TP_CONNECTION_FEATURE_BALANCE))
 		return;
@@ -1097,7 +1085,7 @@ main_window_setup_balance_conn_ready (GObject      *source,
 	gtk_action_set_visible (priv->view_balance_show_in_roster, TRUE);
 
 	/* create the display widget */
-	main_window_setup_balance_create_widget (window, action);
+	main_window_setup_balance_create_widget (window, action, account);
 
 	/* check the current balance and monitor for any changes */
 	uri = tp_connection_get_balance_uri (conn);
@@ -1110,23 +1098,7 @@ main_window_setup_balance_conn_ready (GObject      *source,
 
 	g_signal_connect (conn, "balance-changed",
 		G_CALLBACK (main_window_balance_changed_cb), action);
-}
 
-static void
-main_window_setup_balance (EmpathyMainWindow *window,
-			   TpAccount         *account)
-{
-	TpConnection *conn = tp_account_get_connection (account);
-	GQuark features[] = { TP_CONNECTION_FEATURE_BALANCE, 0 };
-
-	if (conn == NULL)
-		return;
-
-	/* need to prepare the connection:
-	 * store the account on the connection */
-	g_object_set_data (G_OBJECT (conn), "account", account);
-	tp_proxy_prepare_async (conn, features,
-		main_window_setup_balance_conn_ready, window);
 }
 
 static void
@@ -1875,9 +1847,9 @@ main_window_edit_blocked_contacts_cb (GtkAction         *action,
 			G_CALLBACK (gtk_widget_destroy), NULL);
 }
 
-static void
-main_window_edit_preferences_cb (GtkAction         *action,
-				 EmpathyMainWindow *window)
+void
+empathy_main_window_show_preferences (EmpathyMainWindow *window,
+    const gchar *tab)
 {
 	EmpathyMainWindowPriv *priv = GET_PRIV (window);
 
@@ -1890,6 +1862,17 @@ main_window_edit_preferences_cb (GtkAction         *action,
 	} else {
 		gtk_window_present (GTK_WINDOW (priv->preferences));
 	}
+
+	if (tab != NULL)
+		empathy_preferences_show_tab (
+			EMPATHY_PREFERENCES (priv->preferences), tab);
+}
+
+static void
+main_window_edit_preferences_cb (GtkAction         *action,
+				 EmpathyMainWindow *window)
+{
+	empathy_main_window_show_preferences (window, NULL);
 }
 
 static void
@@ -1903,42 +1886,7 @@ static void
 main_window_help_debug_cb (GtkAction         *action,
 			   EmpathyMainWindow *window)
 {
-	GdkDisplay *display;
-	GError *error = NULL;
-	gchar *path;
-	GAppInfo *app_info;
-	GdkAppLaunchContext *context = NULL;
-
-	/* Try to run from source directory if possible */
-	path = g_build_filename (g_getenv ("EMPATHY_SRCDIR"), "src",
-			"empathy-debugger", NULL);
-
-	if (!g_file_test (path, G_FILE_TEST_EXISTS)) {
-		g_free (path);
-		path = g_build_filename (BIN_DIR, "empathy-debugger", NULL);
-	}
-
-	app_info = g_app_info_create_from_commandline (path, NULL, 0, &error);
-	if (app_info == NULL) {
-		DEBUG ("Failed to create app info: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-	display = gdk_display_get_default ();
-	context = gdk_display_get_app_launch_context (display);
-
-	if (!g_app_info_launch (app_info, NULL, (GAppLaunchContext *) context,
-		&error)) {
-		g_warning ("Failed to open debug window: %s", error->message);
-		g_error_free (error);
-		goto out;
-	}
-
-out:
-	tp_clear_object (&app_info);
-	tp_clear_object (&context);
-	g_free (path);
+	empathy_launch_program (BIN_DIR, "empathy-debugger", NULL);
 }
 
 static void
